@@ -3,9 +3,9 @@ package HTTP::Response;
 use strict;
 use warnings;
 
-our $VERSION = '6.18';
+our $VERSION = '6.39';
 
-use base 'HTTP::Message';
+use parent 'HTTP::Message';
 
 use HTTP::Status ();
 
@@ -341,18 +341,11 @@ sub fresh_until
 
 1;
 
+
+__END__
+
 =pod
 
-=encoding UTF-8
-
-=head1 NAME
-
-HTTP::Response - HTTP style response message
-
-=head1 VERSION
-
-version 6.18
-
 =head1 SYNOPSIS
 
 Response objects are returned by the request() method of the C<LWP::UserAgent>:
@@ -645,21 +638,7 @@ description of freshness_lifetime().
 
 L<HTTP::Headers>, L<HTTP::Message>, L<HTTP::Status>, L<HTTP::Request>
 
-=head1 AUTHOR
-
-Gisle Aas <gisle@activestate.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 1994-2017 by Gisle Aas.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
-__END__
-
-
 #ABSTRACT: HTTP style response message
 
